=====
FNAPY
=====

.. image:: https://travis-ci.org/alexandriagroup/fnapy.svg?branch=master
    :target: https://travis-ci.org/alexandriagroup/fnapy


Description
===========

**fnapy** is a Python library using the FnacMarketPlace API to connect to your
own sales application to your FnacMarketplace seller account.  It uses the REST
WebService protocol to exchange data.
